==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_entities/profile_001/Variables.java <==

package net.datastream.schemas.mp_entities.profile_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="VARIABLE1" type="{http://schemas.datastream.net/MP_fields}VARIABLE_Type" minOccurs="0"/>
 *         &lt;element name="VARIABLE2" type="{http://schemas.datastream.net/MP_fields}VARIABLE_Type" minOccurs="0"/>
 *         &lt;element name="VARIABLE3" type="{http://schemas.datastream.net/MP_fields}VARIABLE_Type" minOccurs="0"/>
 *         &lt;element name="VARIABLE4" type="{http://schemas.datastream.net/MP_fields}VARIABLE_Type" minOccurs="0"/>
 *         &lt;element name="VARIABLE5" type="{http://schemas.datastream.net/MP_fields}VARIABLE_Type" minOccurs="0"/>
 *         &lt;element name="VARIABLE6" type="{http://schemas.datastream.net/MP_fields}VARIABLE_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "variable1",
    "variable2",
    "variable3",
    "variable4",
    "variable5",
    "variable6"
})
@XmlRootElement(name = "Variables")
public class Variables {

    @XmlElement(name = "VARIABLE1")
    protected String variable1;
    @XmlElement(name = "VARIABLE2")
    protected String variable2;
    @XmlElement(name = "VARIABLE3")
    protected String variable3;
    @XmlElement(name = "VARIABLE4")
    protected String variable4;
    @XmlElement(name = "VARIABLE5")
    protected String variable5;
    @XmlElement(name = "VARIABLE6")
    protected String variable6;

    /**
     * Obtient la valeur de la propriété variable1.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVARIABLE1() {
        return variable1;
    }

    /**
     * Définit la valeur de la propriété variable1.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVARIABLE1(String value) {
        this.variable1 = value;
    }

    /**
     * Obtient la valeur de la propriété variable2.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVARIABLE2() {
        return variable2;
    }

    /**
     * Définit la valeur de la propriété variable2.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVARIABLE2(String value) {
        this.variable2 = value;
    }

    /**
     * Obtient la valeur de la propriété variable3.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVARIABLE3() {
        return variable3;
    }

    /**
     * Définit la valeur de la propriété variable3.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVARIABLE3(String value) {
        this.variable3 = value;
    }

    /**
     * Obtient la valeur de la propriété variable4.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVARIABLE4() {
        return variable4;
    }

    /**
     * Définit la valeur de la propriété variable4.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVARIABLE4(String value) {
        this.variable4 = value;
    }

    /**
     * Obtient la valeur de la propriété variable5.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVARIABLE5() {
        return variable5;
    }

    /**
     * Définit la valeur de la propriété variable5.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVARIABLE5(String value) {
        this.variable5 = value;
    }

    /**
     * Obtient la valeur de la propriété variable6.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVARIABLE6() {
        return variable6;
    }

    /**
     * Définit la valeur de la propriété variable6.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVARIABLE6(String value) {
        this.variable6 = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_entities/profile_001/Variables.java <==

package net.datastream.schemas.mp_entities.profile_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="VARIABLE1" type="{http://schemas.datastream.net/MP_fields}VARIABLE_Type" minOccurs="0"/>
 *         &lt;element name="VARIABLE2" type="{http://schemas.datastream.net/MP_fields}VARIABLE_Type" minOccurs="0"/>
 *         &lt;element name="VARIABLE3" type="{http://schemas.datastream.net/MP_fields}VARIABLE_Type" minOccurs="0"/>
 *         &lt;element name="VARIABLE4" type="{http://schemas.datastream.net/MP_fields}VARIABLE_Type" minOccurs="0"/>
 *         &lt;element name="VARIABLE5" type="{http://schemas.datastream.net/MP_fields}VARIABLE_Type" minOccurs="0"/>
 *         &lt;element name="VARIABLE6" type="{http://schemas.datastream.net/MP_fields}VARIABLE_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "variable1",
    "variable2",
    "variable3",
    "variable4",
    "variable5",
    "variable6"
})
@XmlRootElement(name = "Variables")
public class Variables {

    @XmlElement(name = "VARIABLE1")
    protected String variable1;
    @XmlElement(name = "VARIABLE2")
    protected String variable2;
    @XmlElement(name = "VARIABLE3")
    protected String variable3;
    @XmlElement(name = "VARIABLE4")
    protected String variable4;
    @XmlElement(name = "VARIABLE5")
    protected String variable5;
    @XmlElement(name = "VARIABLE6")
    protected String variable6;

    /**
     * Gets the value of the variable1 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVARIABLE1() {
        return variable1;
    }

    /**
     * Sets the value of the variable1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVARIABLE1(String value) {
        this.variable1 = value;
    }

    /**
     * Gets the value of the variable2 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVARIABLE2() {
        return variable2;
    }

    /**
     * Sets the value of the variable2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVARIABLE2(String value) {
        this.variable2 = value;
    }

    /**
     * Gets the value of the variable3 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVARIABLE3() {
        return variable3;
    }

    /**
     * Sets the value of the variable3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVARIABLE3(String value) {
        this.variable3 = value;
    }

    /**
     * Gets the value of the variable4 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVARIABLE4() {
        return variable4;
    }

    /**
     * Sets the value of the variable4 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVARIABLE4(String value) {
        this.variable4 = value;
    }

    /**
     * Gets the value of the variable5 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVARIABLE5() {
        return variable5;
    }

    /**
     * Sets the value of the variable5 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVARIABLE5(String value) {
        this.variable5 = value;
    }

    /**
     * Gets the value of the variable6 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVARIABLE6() {
        return variable6;
    }

    /**
     * Sets the value of the variable6 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVARIABLE6(String value) {
        this.variable6 = value;
    }

}
